@@ -11,7 +11,7 @@ def str_as_list(source: str | Any,
 
     :param source: the string value to be worked on
     :param separator: the separator (defaults to ",")
-    :return: a list built from the contents of the source parameter, or that parameter itself, if is not a string
+    :return: a list built from the contents of 'source', or 'source' itself, if is not a string
     """
     result: list[Any]
     if isinstance(source, str):
@@ -116,7 +116,7 @@ def str_get_between(source: str,
 
 def str_get_positional(source: str,
                        list_origin: list[str],
-                       list_dest: list[str]) -> str:
+                       list_dest: list[Any]) -> Any:
     """
     Locate the position of *source* within *list_origin*, and return the element in the same position in *list_dest*.
 
@@ -126,7 +126,7 @@ def str_get_positional(source: str,
     :return: the value positionally corresponding to the source string, or None if not found
     """
     # declare the return variable
-    result: str | None
+    result: Any | None
 
     try:
         pos: int = list_origin.index(source)
@@ -152,3 +152,26 @@ def str_rreplace(source: str,
     """
     return source[::-1].replace(old[::-1], new[::-1], count)[::-1]
 
+
+def str_lower(source: str) -> str:
+    """
+    Safely convert *source* to lower-case.
+
+    If *source* is not a *str*, then it is itself returned.
+
+    :param source: the string to convert to lower-case
+    :return: 'source' in lower-case, or 'source' itself, if is not a string
+    """
+    return source.lower() if isinstance(source, str) else source
+
+
+def str_upper(source: str) -> str:
+    """
+    Safely convert *source* to upper-case.
+
+    If *source* is not a *str*, then it is itself returned.
+
+    :param source: the string to convert to upper-case
+    :return: 'source' in upper-case, or 'source' itself, if it is not a string
+    """
+    return source.upper() if isinstance(source, str) else source
