@@ -24,7 +24,7 @@ def validate_value(attr: str,
     :param max_val: if val is a string, specifies its maximum length; otherwise, specifies its maximum value
     :param values: if provided, requires 'val' to be in it
     :param required:  requires 'val' to be specified;
-    :return: None if val passes validation, or the corresponding error message otherwise
+    :return: 'None' if val passes validation, or the corresponding error message otherwise
     """
     # initialize the return variable
     result: str | None = None
@@ -69,7 +69,7 @@ def validate_value(attr: str,
 
 
 def validate_bool(errors: list[str] | None,
-                  scheme: dict,
+                  scheme: dict[str, Any],
                   attr: str,
                   default: bool = None,
                   required: bool = False,
@@ -79,9 +79,9 @@ def validate_bool(errors: list[str] | None,
 
     If provided, this value must be on of:
         - a *bool*
-        - the string *1*, *t*, or *true*
-        - the string *0*, *f*, or *false*
         - the integer *1* or *0*
+        - the string *1*, *t*, or *true*, case disregarded
+        - the string *0*, *f*, or *false*, case disregarded
 
     :param errors: incidental error messages
     :param scheme: dictionary containing the value to be validated
@@ -89,7 +89,7 @@ def validate_bool(errors: list[str] | None,
     :param default: default value, overiding 'required'
     :param required: specifies whether a value must be provided
     :param logger: optional logger
-    :return: the validated value, or None if validation failed
+    :return: the validated value, or 'None' if validation failed
     """
     # initialize the return variable
     result: bool | None = None
@@ -138,7 +138,7 @@ def validate_bool(errors: list[str] | None,
 
 
 def validate_int(errors: list[str] | None,
-                 scheme: dict,
+                 scheme: dict[str, Any],
                  attr: str,
                  min_val: int = None,
                  max_val: int = None,
@@ -159,7 +159,7 @@ def validate_int(errors: list[str] | None,
                     if 'list', requires the value, if provided, to be in it
     :param required: specifies whether a value must be provided
     :param logger: optional logger
-    :return: the validated value, or None if validation failed
+    :return: the validated value, or 'None' if validation failed
     """
     # initialize the return variable
     result: int | None = None
@@ -174,14 +174,15 @@ def validate_int(errors: list[str] | None,
     # validate it
     if value is None and isinstance(default, int):
         value = default
+    elif isinstance(value, str) and value.isnumeric():
+        value = int(value)
     # 'bool' is subtype of 'int'
     elif value is not None and \
          (isinstance(value, bool) or not isinstance(value, int)):
         # 152: Invalid value {}: must be type {}
         stat = validate_format_error(152, value, "int", f"@{attr}")
-    else:
-        if isinstance(value, str) and value.isnumeric():
-            value = int(value)
+
+    if not stat:
         values = default if isinstance(default, list) else None
         stat = validate_value(attr=attr,
                               val=value,
@@ -189,7 +190,6 @@ def validate_int(errors: list[str] | None,
                               max_val=max_val,
                               values=values,
                               required=required)
-
     if stat:
         __validate_log(errors=errors,
                        err_msg=stat,
@@ -201,7 +201,7 @@ def validate_int(errors: list[str] | None,
 
 
 def validate_float(errors: list[str] | None,
-                   scheme: dict,
+                   scheme: dict[str, Any],
                    attr: str,
                    min_val: float = None,
                    max_val: float = None,
@@ -222,7 +222,7 @@ def validate_float(errors: list[str] | None,
                     if 'list', requires the value, if provided, to be in it
     :param required: specifies whether a value must be provided
     :param logger: optional logger
-    :return: the validated value, or None if validation failed
+    :return: the validated value, or 'None' if validation failed
     """
     # initialize the return variable
     result: float | None = None
@@ -237,14 +237,15 @@ def validate_float(errors: list[str] | None,
     # validate it
     if value is None and isinstance(default, int | float):
         value = float(default)
+    elif (isinstance(value, int) and not isinstance(value, bool)) or \
+          (isinstance(value, str) and value.replace(".", "", 1).isnumeric()):
+        value = float(value)
     elif isinstance(value, bool) or \
-         value is not None and not isinstance(value, int | float):
+         (value is not None and not isinstance(value, int | float)):
         # 152: Invalid value {}: must be type {}
         stat = validate_format_error(152, value, "float", f"@{attr}")
-    else:
-        if (isinstance(value, int) and not isinstance(value, bool)) or \
-           (isinstance(value, str) and value.replace(".", "", 1).isnumeric()):
-            value = float(value)
+
+    if not stat:
         values = default if isinstance(default, list) else None
         stat = validate_value(attr=attr,
                               val=value,
@@ -252,7 +253,6 @@ def validate_float(errors: list[str] | None,
                               max_val=max_val,
                               values=values,
                               required=required)
-
     if stat:
         __validate_log(errors=errors,
                        err_msg=stat,
@@ -264,7 +264,7 @@ def validate_float(errors: list[str] | None,
 
 
 def validate_str(errors: list[str] | None,
-                 scheme: dict,
+                 scheme: dict[str, Any],
                  attr: str,
                  min_length: int = None,
                  max_length: int = None,
@@ -323,7 +323,7 @@ def validate_str(errors: list[str] | None,
 
 
 def validate_date(errors: list[str] | None,
-                  scheme: dict,
+                  scheme: dict[str, Any],
                   attr: str,
                   day_first: bool = False,
                   default: date = None,
@@ -341,7 +341,7 @@ def validate_date(errors: list[str] | None,
     :param default: optional default value, overrides 'required'
     :param required: specifies whether a value must be provided
     :param logger: optional logger
-    :return: the validated value, or None if validation failed
+    :return: the validated value, or 'None' if validation failed
     """
     # import needed module
     from .datetime_pomes import date_parse
@@ -382,7 +382,7 @@ def validate_date(errors: list[str] | None,
 
 
 def validate_datetime(errors: list[str] | None,
-                      scheme: dict,
+                      scheme: dict[str, Any],
                       attr: str,
                       day_first: bool = True,
                       default: datetime = None,
@@ -400,7 +400,7 @@ def validate_datetime(errors: list[str] | None,
     :param default: optional default value, overrides 'required'
     :param required: specifies whether a value must be provided
     :param logger: optional logger
-    :return: the validated value, or None if validation failed
+    :return: the validated value, or 'None' if validation failed
     """
     # import needed module
     from .datetime_pomes import datetime_parse
@@ -413,7 +413,7 @@ def validate_datetime(errors: list[str] | None,
     suffix: str = attr[pos:]
 
     # obtain and validate the value
-    value: str = scheme[suffix]
+    value: str = scheme.get(suffix)
     if value:
         result = datetime_parse(dt_str=value,
                                 dayfirst=day_first)
@@ -438,7 +438,7 @@ def validate_datetime(errors: list[str] | None,
 
 
 def validate_ints(errors: list[str] | None,
-                  scheme: dict,
+                  scheme: dict[str, Any],
                   attr: str,
                   min_val: int = None,
                   max_val: int = None,
@@ -456,16 +456,18 @@ def validate_ints(errors: list[str] | None,
     :param max_val:  the maximum value accepted
     :param required: whether the list of values must be provided
     :param logger: optional logger
-    :return: the list of validated values, or None if validation failed
+    :return: the list of validated values, '[]' if not required and no values found, or 'None' if validation failed
     """
     # initialize the return variable
-    result: list[Any] | None = None
+    result: list[Any] | None = []
 
     stat: str | None = None
     pos: int = attr.rfind(".") + 1
     suffix: str = attr[pos:]
-    try:
-        values: list[Any] = scheme[suffix]
+
+    # obtain the values
+    values: list[Any] = scheme.get(suffix)
+    if values:
         if isinstance(values, list):
             result = []
             if len(values) > 0:
@@ -485,21 +487,21 @@ def validate_ints(errors: list[str] | None,
         else:
             # 152: Invalid value {}: must be type {}
             stat = validate_format_error(152, result, "list", f"@{attr}")
-    except (KeyError, TypeError):
-        if required:
-            # 121: Required attribute
-            stat = validate_format_error(121, f"@{attr}")
+    elif required:
+        # 121: Required attribute
+        stat = validate_format_error(121, f"@{attr}")
 
     if stat:
         __validate_log(errors=errors,
                        err_msg=stat,
                        logger=logger)
+        result = None
 
     return result
 
 
 def validate_strs(errors: list[str] | None,
-                  scheme: dict,
+                  scheme: dict[str, Any],
                   attr: str,
                   min_length: int = None,
                   max_length: int = None,
@@ -517,16 +519,18 @@ def validate_strs(errors: list[str] | None,
     :param max_length:  optional maximum length accepted
     :param required: whether the list of values must be provided
     :param logger: optional logger
-    :return: the list of validated values, or None if validation failed
+    :return: the list of validated values, '[]' if not required and no values found, or 'None' if validation failed
     """
     # initialize the return variable
-    result: list[Any] | None = None
+    result: list[Any] | None = []
 
     stat: str | None = None
     pos: int = attr.rfind(".") + 1
     suffix: str = attr[pos:]
-    try:
-        values: list[Any] = scheme[suffix]
+
+    # obtain the values
+    values: list[Any] = scheme.get(suffix)
+    if values:
         if isinstance(values, list):
             result = []
             if len(values) > 0:
@@ -546,15 +550,15 @@ def validate_strs(errors: list[str] | None,
         else:
             # 152: Invalid value {}: must be type {}
             stat = validate_format_error(152, result, "list", f"@{attr}")
-    except (KeyError, TypeError):
-        if required:
-            # 121: Required attribute
-            stat = validate_format_error(121, f"@{attr}")
+    elif required:
+        # 121: Required attribute
+        stat = validate_format_error(121, f"@{attr}")
 
     if stat:
         __validate_log(errors=errors,
                        err_msg=stat,
                        logger=logger)
+        result = None
 
     return result
 
@@ -607,7 +611,7 @@ def validate_format_error(error_id: int,
     return result
 
 
-def validate_format_errors(errors: list[str]) -> list[dict]:
+def validate_format_errors(errors: list[str]) -> list[dict[str, str]]:
     """
     Build and return a list of dicts from the list of errors *errors*.
 
@@ -634,12 +638,12 @@ def validate_format_errors(errors: list[str]) -> list[dict]:
         # was the attribute's name found ?
         if pos == -1:
             # no
-            out_error: dict = {}
+            out_error: dict[str, str] = {}
             desc: str = error
         else:
             # yes
             term: str = "attribute" if VALIDATION_MSG_LANGUAGE == "en" else "atributo"
-            out_error: dict = {term: error[pos + 1:]}
+            out_error: dict[str, str] = {term: error[pos + 1:]}
             desc: str = error[:pos - 1]
 
         # does the text contain an error code ?
@@ -657,7 +661,7 @@ def validate_format_errors(errors: list[str]) -> list[dict]:
     return result
 
 
-def validate_unformat_errors(errors: list[dict | str]) -> list[str]:
+def validate_unformat_errors(errors: list[dict[str, str] | str]) -> list[str]:
     """
     Extract and return the list of errors used to build the list of dicts *errors*.
 
